netapp_ontap.models.svm_cifs_service API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.svm_cifs_service`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class SvmCifsServiceSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the SvmCifsService object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `ad_domain: AdDomainSvm GET POST`

    The ad_domain field of the svm_cifs_service.

  `allowed: bool GET POST PATCH`

    If this is set to true, an SVM administrator can manage the CIFS service. If it is false, only the cluster administrator can manage the service.

  `auth_style: str GET`

    Authentication type.

    Valid choices:

    - domain
    - workgroup
  `domain_workgroup: str GET`

    The NetBIOS name of the domain or workgroup associated with the CIFS server.

  `enabled: bool GET POST`

    If allowed, setting to true enables the CIFS service.

  `links: SelfLink GET`

    The links field of the svm_cifs_service.

  `name: str GET POST`

    The NetBIOS name of the CIFS server.

    Example: CIFS1

  `workgroup: str GET POST PATCH`

    The workgroup name.

    Example: workgrp1